==> TopdataTopFinderProSW6-v6.5.2.zip: TopdataTopFinderProSW6/src/Resources/app/storefront/src/main.js <==
import PluginManager from 'src/plugin-system/plugin.manager';
import TopdataTopFinderProSearchDevice from './plugin/topdata-top-finder-pro.search-device.plugin';
import TopdataTopFinderProProductDetailDeviceTab from "./plugin/topdata-top-finder-pro.product-detail-device-tab.plugin";
import TopdataTopFinderProFinder from "./plugin/topdata-top-finder-pro.finder.plugin";
import TopdataTopFinderProPopupFinder from "./plugin/topdata-top-finder-pro.popup-finder.plugin";
import TopdataTopFinderProDeviceSlider from "./plugin/topdata-top-finder-pro.device-slider.plugin";
import TopdataTopFinderProDeviceWrapper from "./plugin/topdata-top-finder-pro.device-wrapper.plugin";
import TopdataTopFinderProDeviceList from "./plugin/topdata-top-finder-pro.device-list.plugin";

PluginManager.register(
    'TopdataTopFinderProSearchDevice',
    TopdataTopFinderProSearchDevice,
    '[data-search-device-form]'
);

PluginManager.register(
    'TopdataTopFinderProProductDetailDeviceTab',
    TopdataTopFinderProProductDetailDeviceTab,
    '.top-finder-product-devices-load-tab'
);

PluginManager.register(
    'TopdataTopFinderProFinder',
    TopdataTopFinderProFinder,
    '.topdata-top-finder-pro-container'
);

PluginManager.register(
    'TopdataTopFinderProPopupFinder',
    TopdataTopFinderProPopupFinder,
    '#topdata-finder-popup'
);

PluginManager.register(
    'TopdataTopFinderProDeviceSlider',
    TopdataTopFinderProDeviceSlider,
    '.top-finder-devices-slider'
);

PluginManager.register(
    'TopdataTopFinderProDeviceList',
    TopdataTopFinderProDeviceList,
    '.account-device-list'
);


PluginManager.register(
    'TopdataTopFinderProDeviceWrapper',
    TopdataTopFinderProDeviceWrapper,
    '.topfinder-device-wrapper'
);

==> TopdataTopFinderProSW6-v8.1.5.zip: TopdataTopFinderProSW6/src/Resources/app/storefront/src/main.js <==
// Register them via the existing PluginManager
const PluginManager = window.PluginManager;

import TopdataTopFinderProSearchDevice from './plugin/topdata-top-finder-pro.search-device.plugin';
import TopdataTopFinderProProductDetailDeviceTab from "./plugin/topdata-top-finder-pro.product-detail-device-tab.plugin";
import TopdataTopFinderProFinder from "./plugin/topdata-top-finder-pro.finder.plugin";
import TopdataTopFinderProPopupFinder from "./plugin/topdata-top-finder-pro.popup-finder.plugin";
import TopdataTopFinderProDeviceSlider from "./plugin/topdata-top-finder-pro.device-slider.plugin";
import TopdataTopFinderProDeviceWrapper from "./plugin/topdata-top-finder-pro.device-wrapper.plugin";
import TopdataTopFinderProDeviceList from "./plugin/topdata-top-finder-pro.device-list.plugin";


PluginManager.register(
    'TopdataTopFinderProSearchDevice',
    TopdataTopFinderProSearchDevice,
    '[data-search-device-form]'
);


PluginManager.register(
    'TopdataTopFinderProProductDetailDeviceTab',
    TopdataTopFinderProProductDetailDeviceTab,
    '.top-finder-product-devices-load-tab'
);
//
PluginManager.register(
    'TopdataTopFinderProFinder',
    TopdataTopFinderProFinder,
    '.topdata-top-finder-pro-container'
);

PluginManager.register(
    'TopdataTopFinderProPopupFinder',
    TopdataTopFinderProPopupFinder,
    '#topdata-finder-popup'
);

PluginManager.register(
    'TopdataTopFinderProDeviceSlider',
    TopdataTopFinderProDeviceSlider,
    '.top-finder-devices-slider'
);

PluginManager.register(
    'TopdataTopFinderProDeviceList',
    TopdataTopFinderProDeviceList,
    '.account-device-list'
);


PluginManager.register(
    'TopdataTopFinderProDeviceWrapper',
    TopdataTopFinderProDeviceWrapper,
    '.topfinder-device-wrapper'
);
